==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディタの外部から変更されました。変更点を適用できません。",
    "File could not be loaded. Please check your internet connection." : "ファイルを読み込めませんでした。 インターネット接続を確認してください。",
    "Retry" : "再試行",
    "Last saved {lastSaved}" : "最終保存日 {lastSaved}",
    "Unpushed changes" : "プッシュされていない変更",
    "Unsaved changes" : "保存していない変更点",
    "Enter your name so other users can see who is editing" : "自分の名前を入力して、他のユーザーの誰が編集中かを確認する",
    "Edit guest name" : "ゲスト名を編集",
    "Save guest name" : "ゲスト名を保存",
    "Insert image" : "画像の挿入",
    "Add link" : "リンクを追加",
    "_and %n other editor_::_and %n other editors_" : ["他に%n人の編集者"],
    "Show rich workspaces" : "豊富なワークスペースを表示",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "New text document" : "新しいテキストドキュメント",
    "Edit" : "編集",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Bold" : "太字",
    "Italic" : "斜体",
    "Strikethrough" : "取り消し線",
    "Paragraph" : "段落",
    "Headings" : "見出し",
    "Heading 1" : "見出し1",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "Heading 6" : "見出し6",
    "Unordered list" : "番号なしのリスト",
    "Ordered list" : "順序付きリスト",
    "ToDo list" : "ToDo リスト",
    "Blockquote" : "引用",
    "Code block" : "コードブロック",
    "Network connection error: Could not connect to the document" : "ネットワーク接続エラー：ドキュメントの接続ができませんでした",
    "Last save {lastSave}" : "最終保存 {lastSave}",
    "Show image" : "画像を表示する",
    "Show file" : "ファイルを表示する"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディタの外部から変更されました。変更点を適用できません。",
    "File could not be loaded. Please check your internet connection." : "ファイルを読み込めませんでした。 インターネット接続を確認してください。",
    "Retry" : "再試行",
    "Last saved {lastSaved}" : "最終保存日 {lastSaved}",
    "Unpushed changes" : "プッシュされていない変更",
    "Unsaved changes" : "保存していない変更点",
    "Enter your name so other users can see who is editing" : "自分の名前を入力して、他のユーザーの誰が編集中かを確認する",
    "Edit guest name" : "ゲスト名を編集",
    "Save guest name" : "ゲスト名を保存",
    "Insert image" : "画像の挿入",
    "_and %n other editor_::_and %n other editors_" : ["他に%n人の編集者"],
    "Show rich workspaces" : "Readme.mdを表示",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "New text document" : "新しいテキストドキュメント",
    "Edit" : "編集",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Bold" : "太字",
    "Italic" : "斜体",
    "Strikethrough" : "取り消し線",
    "Headings" : "見出し",
    "Heading 1" : "見出し1",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "Heading 6" : "見出し6",
    "Unordered list" : "番号なしのリスト",
    "Ordered list" : "順序付きリスト",
    "ToDo list" : "ToDo リスト",
    "Blockquote" : "引用",
    "Code block" : "コードブロック",
    "Last save {lastSave}" : "最終保存 {lastSave}",
    "Add link" : "リンクを追加",
    "Show image" : "画像を表示する",
    "Show file" : "ファイルを表示する",
    "Paragraph" : "段落"
},
"nplurals=1; plural=0;");
